# SuspendPolicy

Suspend methods. Specify a way to suspend a subscription. See [Suspend Date](https://knowledgecenter.zuora.com/BC_Subscription_Management/Subscriptions/Suspend_a_Subscription#Suspend_Date) for more information. 

## Enum

* `TODAY` (value: `'Today'`)

* `ENDOFLASTINVOICEPERIOD` (value: `'EndOfLastInvoicePeriod'`)

* `FIXEDPERIODSFROMTODAY` (value: `'FixedPeriodsFromToday'`)

* `SPECIFICDATE` (value: `'SpecificDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


